package people;
/**
 * This class represents a human and stores the name, the date of birth and 
 * the gender information about them.
 */
public class Human {
  public static final boolean MALE = true;
  public static final boolean FEMALE = false;
  
  protected String name;
  protected int birthDate;
  protected boolean isMale;
  
  /**
   * Constructs a default human object.
   * Sets the name to "Senki", the date of birth to "1900" and the gender is "male" 
   * using another constructor of this class.
   */
  public Human() {
    this("Senki", 1900, Human.MALE);
  }

  /**
   * Constructs a human object and sets the fields based on the specified parameters.
   * @param name the name of the human
   * @param birthDate the date of birth of the human
   * @param isMale the gender of the human
   */
  public Human(String name, int birthDate, boolean isMale) {
    this.name = name;
    this.birthDate = birthDate;
    this.isMale = isMale;
  }
  
  /**
   * Constructs a human by cloning the specified human.
   * @param h to be cloned
   */
  public Human(Human h) {
    this.name = h.name;
    this.birthDate = h.birthDate;
    this.isMale = h.isMale;
  }
  
  @Override
  public Object clone() {
    return new Human(this);
  }

  /**
   * Returns the name of the current human.
   * @return the name of the human
   */
  public String getName() {
    return name;
  }

  /**
   * Sets the specified name for the current human.
   * @param name to be set
   */
  public void setName(String name) {
    this.name = name;
  }

  /**
   * Returns the date of birth of the current human.
   * @return the date of birth
   */
  public int getBirthDate() {
    return birthDate;
  }

  /**
   * Sets the specified date of birth for the current human.
   * @param birthDate to be set
   */
  public void setBirthDate(int birthDate) {
    this.birthDate = birthDate;
  }

  /**
   * Returns the gender of the current human.
   * @return gender
   */
  public boolean isMale() {
    return isMale;
  }

  /**
   * Sets the specified gender for the current human.
   * @param isMale to be set
   */
  public void setMale(boolean isMale) {
    this.isMale = isMale;
  }

  @Override
  public String toString() {
    return "Human [name=" + name + ", birthDate=" + birthDate + ", isMale=" + isMale + "]";
  }
  
  /**
   * Prints the specified parameters to the screen as a human.
   * @param name name of the human
   * @param birthDate date of birth of the human
   * @param isMale gender of the human
   */
  public static void print(String name, int birthDate, boolean isMale) {
    System.out.println("Human [name=" + name + ", birthDate=" + birthDate + ", isMale=" + isMale + "]");
  }
  
  /**
   * Prints the specified human to the screen.
   * @param h to be printed
   */
  public static void print(Human h) {
    print(h.name, h.birthDate, h.isMale);
  }
  
  public void kryptoniteRay() {
    System.out.println(this + " gets some kryptonite ray... and what's???");
  }
  
}
